==> nextcloud-16.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/lt_LT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Vidutinė apkrova",
    "Last minute" : "Paskutinę minutę",
    "Memory info not available" : "Atminties informacija neprieinama",
    "Total" : "Iš viso",
    "Current usage" : "Dabartinis sunaudojimas",
    "Users" : "Naudotojai",
    "Groups" : "Grupės",
    "Links" : " Nuorodos",
    "Federated sent" : "Federaciškai išsiųstas",
    "Federated received" : "Federaciškai gautas",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Monitoring" : "Stebėjimas",
    "Memory" : "Atmintis",
    "Disk" : "Diskas",
    "Filesystem" : "Failų sistema",
    "Size" : "Dydis",
    "Files:" : "Failai:",
    "Storages:" : "Saugyklos:",
    "Free Space:" : "Laisva vieta:",
    "Network" : "Tinklas",
    "Gateway" : "Tinklų sietuvas",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktyvūs naudotojai",
    "Shares" : "Viešiniai",
    "PHP" : "PHP",
    "Version:" : "Versija:",
    "Memory Limit:" : "Atminties limitas:",
    "Max Execution Time:" : "Maksimalus vykdymo laikas:",
    "Upload max size:" : "Maksimalus įkeliamo failo dydis:",
    "Database" : "Duomenų bazė",
    "Type:" : "Tipas:",
    "Size:" : "Dydis:",
    "External monitoring tool" : "Išorinis stebėjimo įrankis",
    "Did you know?" : "Ar žinojote?",
    "Last 24 hours" : "Paskutinės 24 valandos",
    "Last 1 hour" : "Paskutinė valanda",
    "Last 5 mins" : "Paskutinės 5 minutės",
    "CPU load" : "Procesoriaus apkrova",
    "Memory usage" : "Atminties sunaudojimas",
    "Storage" : "Saugykla",
    "Users:" : "Naudotojai:",
    "Nextcloud" : "Nextcloud"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/serverinfo/l10n/lt_LT.js <==
OC.L10N.register(
    "serverinfo",
    {
    "Load average" : "Vidutinė apkrova",
    "Last minute" : "Paskutinę minutę",
    "Memory info not available" : "Atminties informacija neprieinama",
    "Total" : "Iš viso",
    "Current usage" : "Dabartinis sunaudojimas",
    "Users" : "Naudotojai",
    "Groups" : "Grupės",
    "Links" : " Nuorodos",
    "Federated sent" : "Federaciškai išsiųstas",
    "Federated received" : "Federaciškai gautas",
    "Copy" : "Kopijuoti",
    "Copied!" : "Nukopijuota!",
    "Not supported!" : "Nepalaikoma!",
    "Monitoring" : "Stebėjimas",
    "Operating System" : "Operacinė sistema",
    "Memory" : "Atmintis",
    "Disk" : "Diskas",
    "Filesystem" : "Failų sistema",
    "Size" : "Dydis",
    "Files:" : "Failai:",
    "Storages:" : "Saugyklos:",
    "Free Space:" : "Laisva vieta:",
    "Network" : "Tinklas",
    "DNS" : "DNS",
    "Gateway" : "Tinklų sietuvas",
    "MAC" : "MAC",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Active users" : "Aktyvūs naudotojai",
    "Total users:" : "Iš viso naudotojų:",
    "Shares" : "Viešiniai",
    "PHP" : "PHP",
    "Version:" : "Versija:",
    "Memory Limit:" : "Atminties limitas:",
    "Max Execution Time:" : "Maksimalus vykdymo laikas:",
    "Upload max size:" : "Maksimalus įkeliamo failo dydis:",
    "Database" : "Duomenų bazė",
    "Type:" : "Tipas:",
    "Size:" : "Dydis:",
    "External monitoring tool" : "Išorinis stebėjimo įrankis",
    "Did you know?" : "Ar žinojote?",
    "Last 24 hours" : "Paskutinės 24 valandos",
    "Last 1 hour" : "Paskutinė valanda",
    "Last 5 mins" : "Paskutinės 5 minutės",
    "CPU load" : "Procesoriaus apkrova",
    "Memory usage" : "Atminties sunaudojimas",
    "Storage" : "Saugykla",
    "Users:" : "Naudotojai:",
    "Nextcloud" : "Nextcloud",
    "Apps installed:" : "Įdiegta programėlių:",
    "Apps updates available:" : "Yra prieinama atnaujinimų programėlėms:"
},
"nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
